@@ -40,6 +40,7 @@ extern void mail_conf_flush(void);
 extern void mail_conf_update(const char *, const char *);
 extern const char *mail_conf_lookup(const char *);
 extern const char *mail_conf_eval(const char *);
+extern const char *mail_conf_eval_once(const char *);
 extern const char *mail_conf_lookup_eval(const char *);
 
  /*
@@ -52,12 +53,16 @@ extern int get_mail_conf_bool(const char *, int);
 extern int get_mail_conf_time(const char *, const char *, int, int);
 extern int get_mail_conf_nint(const char *, const char *, int, int);
 extern char *get_mail_conf_raw(const char *, const char *, int, int);
+extern int get_mail_conf_nbool(const char *, const char *);
 
 extern char *get_mail_conf_str2(const char *, const char *, const char *, int, int);
 extern int get_mail_conf_int2(const char *, const char *, int, int, int);
 extern long get_mail_conf_long2(const char *, const char *, long, long, long);
 extern int get_mail_conf_time2(const char *, const char *, int, int, int, int);
 extern int get_mail_conf_nint2(const char *, const char *, int, int, int);
+extern void check_mail_conf_str(const char *, const char *, int, int);
+extern void check_mail_conf_time(const char *, int, int, int);
+extern void check_mail_conf_int(const char *, int, int, int);
 
  /*
   * Lookup with function-call defaults.
@@ -69,6 +74,7 @@ extern int get_mail_conf_bool_fn(const char *, int (*) (void));
 extern int get_mail_conf_time_fn(const char *, const char *(*) (void), int, int, int);
 extern int get_mail_conf_nint_fn(const char *, const char *(*) (void), int, int);
 extern char *get_mail_conf_raw_fn(const char *, const char *(*) (void), int, int);
+extern int get_mail_conf_nbool_fn(const char *, const char *(*) (void));
 
  /*
   * Update dictionary.
@@ -81,6 +87,10 @@ extern void set_mail_conf_time(const char *, const char *);
 extern void set_mail_conf_time_int(const char *, int);
 extern void set_mail_conf_nint(const char *, const char *);
 extern void set_mail_conf_nint_int(const char *, int);
+extern void set_mail_conf_nbool(const char *, const char *);
+
+#define set_mail_conf_nbool_int(name, value) \
+    set_mail_conf_nbool((name), (value) ? CONFIG_BOOL_YES : CONFIG_BOOL_NO)
 
  /*
   * Tables that allow us to selectively copy values from the global
@@ -140,6 +150,12 @@ typedef struct {
     int     max;			/* upper bound or zero */
 } CONFIG_NINT_TABLE;
 
+typedef struct {
+    const char *name;			/* config variable name */
+    const char *defval;			/* default value */
+    int    *target;			/* pointer to global variable */
+} CONFIG_NBOOL_TABLE;
+
 extern void get_mail_conf_str_table(const CONFIG_STR_TABLE *);
 extern void get_mail_conf_int_table(const CONFIG_INT_TABLE *);
 extern void get_mail_conf_long_table(const CONFIG_LONG_TABLE *);
@@ -147,6 +163,7 @@ extern void get_mail_conf_bool_table(const CONFIG_BOOL_TABLE *);
 extern void get_mail_conf_time_table(const CONFIG_TIME_TABLE *);
 extern void get_mail_conf_nint_table(const CONFIG_NINT_TABLE *);
 extern void get_mail_conf_raw_table(const CONFIG_RAW_TABLE *);
+extern void get_mail_conf_nbool_table(const CONFIG_NBOOL_TABLE *);
 
  /*
   * Tables to initialize parameters from the global configuration file or
@@ -198,12 +215,19 @@ typedef struct {
     int     max;			/* upper bound or zero */
 } CONFIG_NINT_FN_TABLE;
 
+typedef struct {
+    const char *name;			/* config variable name */
+    const char *(*defval) (void);	/* default value provider */
+    int    *target;			/* pointer to global variable */
+} CONFIG_NBOOL_FN_TABLE;
+
 extern void get_mail_conf_str_fn_table(const CONFIG_STR_FN_TABLE *);
 extern void get_mail_conf_int_fn_table(const CONFIG_INT_FN_TABLE *);
 extern void get_mail_conf_long_fn_table(const CONFIG_LONG_FN_TABLE *);
 extern void get_mail_conf_bool_fn_table(const CONFIG_BOOL_FN_TABLE *);
 extern void get_mail_conf_raw_fn_table(const CONFIG_RAW_FN_TABLE *);
 extern void get_mail_conf_nint_fn_table(const CONFIG_NINT_FN_TABLE *);
+extern void get_mail_conf_nbool_fn_table(const CONFIG_NBOOL_FN_TABLE *);
 
 /* LICENSE
 /* .ad
